<?php

namespace Drupal\imce_rename\Plugin\ImcePlugin;

use Drupal\imce\Imce;
use Drupal\imce\ImcePluginBase;
use Drupal\imce\ImceFM;

/**
 * Defines Imce Rename plugin.
 *
 * @ImcePlugin(
 *   id = "rename",
 *   label = "Rename",
 *   operations = {
 *     "rename" = "opRename"
 *   }
 * )
 */
class Rename extends ImcePluginBase {

  /**
   * {@inheritdoc}
   */
  public function permissionInfo() {
    return [
      'rename_images' => $this->t('Rename images'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildPage(array &$page, ImceFM $fm) {
    if ($fm->hasPermission('rename_images')) {
      $page['#attached']['library'][] = 'imce_rename/drupal.imce.rename';
    }
  }

  /**
   * Operation handler: rename.
   */
  public function opRename(ImceFM $fm) {
    $old_name = $fm->selection[0]->name;
    $folder = $fm->activeFolder;
    $old_file = $folder->getItem($old_name);

    // Check type.
    if ($old_file->type == 'file') {
      $new_name = $fm->getPost('new_name') . '.' . pathinfo($old_name, PATHINFO_EXTENSION);
      $new_uri = $fm->activeFolder->getUri() . '/' . $new_name;
      $old_uri = $old_file->getUri();

      if ($old_name == $new_name) {
        drupal_set_message(t('Failed to rename file "@old_file" to "@new_file" because "@new_file" already exists', [
          '@old_file' => utf8_encode(basename($old_uri)),
          '@new_file' => utf8_encode(basename($new_uri)),
        ]), 'error');
        return;
      }

      $file = Imce::getFileEntity($old_uri);
      $move = file_move($file, $new_uri, FILE_EXISTS_ERROR);
      $move->setFilename($new_name);
      $move->save();

      // Validate message.
      if ($move) {
        drupal_set_message(t('Rename successful! Renamed "@old_file" to "@new_file"', [
          '@old_file' => utf8_encode(basename($old_uri)),
          '@new_file' => utf8_encode(basename($new_uri)),
        ]));
        $folder->addFile($new_name)->addToJs();
        $folder->getItem($old_name)->removeFromJs();
      }
      else {
        drupal_set_message(t('Failed to rename file "@old_file" to "@new_file" because "@new_file" already exists', [
          '@old_file' => utf8_encode(basename($old_uri)),
          '@new_file' => utf8_encode(basename($new_uri)),
        ]), 'error');
      }
    }
    elseif ($old_file->type == 'folder') {
      drupal_set_message(t('Sorry, but rename a folder is not available yet'));
    }
  }

}
